# Serene Bach plugin for recent comment list with time.
#
# Release 1.00 (July 19,2006)
#
# This software is provided as-is. You may use it for commercial or 
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2005-2006 Yujiro Araki

package sb::Plugin::RecentCommentWithTime;

use sb::Plugin ();
use vars qw($js,@history);

sb::Plugin->register_plugin(
    'lang' => {
        'ja' => 'euc',
        'en' => 'ascii',
    },
    'text' => {
        'type'    => 'cms',
        'name'    => 'RecentCommentWithTme',
        'text'    => 'Recent Comment With Time',
        'author'  => 'Yujiro Araki',
        'detail'  => 'http://www.koikikukan.com/',
        'version' => '1.00',
    },
    'data' => 0,
    'file' => 'recentcommentwithtime.txt',
);

# register callback function to cms entry point
sb::Plugin->register_content_module(
    'type'     => 'main',
    'callback' => \&sb::Content::RecentCommentWithTime::_list_comment_with_time,
    'field'    => 'recent_comment_with_time',
);

package sb::Content::RecentCommentWithTime;

sub _list_comment_with_time { # RgXg
    my $cms = shift;
    my %var = @_;
    my $num = 0;
    my @linklist = ('<ul>');
    my @array = sb::Data->load('Message',
        'sort' => 'date',
        'cond' => {'stat'=>1},
        'order'=> 1,
    );
    foreach my $list ( @array )
    {
        my $entry = sb::Data->load('Entry','id'=>$list->eid);
        next if (!$entry or $entry->stat == 0 or $entry->acm == 0);
        my $url  = $entry->permalink(
            'cat'=>$var{'cat'},
            'mode'=>'com',
            'type'=>$var{'conf'}->value('conf_entry_archive')
        );
        my $subj = $entry->subj;
        my $date = sb::Time->format(
            'time'=>$list->date,
            'form'=>$var{'conf'}->value('conf_dateinlist'),
            'zone'=>$var{'conf'}->value('conf_timezone')
        );
        my $arrow = $var{'lang'}->string('parts_arrow');
        my $author = $list->auth;
        my $time = $list->date;
        push(@linklist,qq|<li>$subj<br />$arrow <a href="$url">$author$date</a> <span class="new">$time</span></li>|);
        $num++;
        last if ($num == $var{'conf'}->value('conf_com_disp'));
    }
    push(@linklist,'</ul>');
    $cms->num(0);
    $cms->tag('recent_comment_list_with_time'=>join("\n",@linklist));
    return (@linklist > 2) ? 1 : 0;
}

1;
__END__
